/*
 * Copyright 2000-2017 JetBrains s.r.o.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
package com.intellij.stats.completion

import com.intellij.openapi.components.ApplicationComponent
import com.intellij.stats.logger.EventLoggerWithValidation
import com.intellij.stats.logger.LogFileManager
import com.intellij.stats.logger.ClientSessionValidator
import com.intellij.stats.storage.FilePathProvider
import java.util.*

class CompletionFileLoggerProvider(
        filePathProvider: FilePathProvider,
        private val installationIdProvider: InstallationIdProvider
) : ApplicationComponent, CompletionLoggerProvider() {

  private val logFileManager = LogFileManager(filePathProvider)
  private val eventLogger = EventLoggerWithValidation(logFileManager, ClientSessionValidator())

  override fun disposeComponent() {
    eventLogger.dispose()
    logFileManager.flush()
  }

  override fun newCompletionLogger(): CompletionLogger {
    val installationUID = installationIdProvider.installationId()
    val completionUID = UUID.randomUUID().toString()
    return CompletionFileLogger(installationUID.shortedUUID(), completionUID.shortedUUID(), eventLogger)
  }
}

private fun String.shortedUUID(): String {
  val start = this.lastIndexOf('-')
  if (start > 0 && start + 1 < this.length) {
    return this.substring(start + 1)
  }
  return this
}